CKEDITOR.plugins.setLang('youtube', 'ar', {
	button : 'شيفرة تضمين اليوتيوب',
	title : 'شيفرة تضمين اليوتيوب',
	txtEmbed : 'الصق شيفرة التضمين هنا',
	txtUrl : 'الصق رابط فيديو اليوتيوب',
	txtWidth : 'العرض',
	txtHeight : 'الطول',
	chkRelated : 'اظهر الفيديوهات المقترحة في نهاية الفيديو',
	txtStartAt : 'ابدأ عند (ss او mm:ss او hh:mm:ss)',
	chkPrivacy : 'تفعيل وضع تحسين الخصوصية',
	chkOlderCode : 'استخدم شيفرة التضمين القديمة',
	chkAutoplay : 'Autoplay',
	chkControls: 'إظهار عناصر التحكم بالمشغّل',
	noCode : 'يجب عليك ادخال شيفرة التضمين او الرابط',
	invalidEmbed : 'شيفرة التضمين التي قمت بإدخالها تبدو غير صحيحة',
	invalidUrl : 'الرابط الذي قمت بإدخاله يبدو غير صحيح',
	or : 'او',
	noWidth : 'يجب عليك ادخال العرض',
	invalidWidth : 'يجب عليك ادخال عرض صحيح',
	noHeight : 'يجب عليك ادخال الطول',
	invalidHeight : 'يجب عليك ادخال طول صحيح',
	invalidTime : 'يجب عليك ادخال وقت بداية صحيح',
	txtResponsive : 'Responsive video'
});
